@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_2 $
-// $Id: platform_qpe.cpp,v 1.29 2004/04/01 10:45:31 yamaken Exp $
+// $Name: IMKIT_0_4_3 $
+// $Id: platform_qpe.cpp,v 1.30 2004/04/29 03:32:47 yamaken Exp $
 
 // This file contains some code fragments from Qtopia GPL
 // (qtopia-free-1.7.0/src/server/inputmethods.cpp). Original
@@ -519,6 +519,9 @@ IMKitImpl::qcopReceive(const QCString &msg, const QByteArray &data) {
     int unicode, keycode, modifiers, is_press, autorepeat;
 
     stream >> unicode >> keycode >> modifiers >> is_press >> autorepeat;
+    qDebug("IMKitImpl::qcopReceive()"
+           " unicode=%x, keycode=%x, is_press=%d, autorepeat=%d",
+           unicode, keycode, is_press, autorepeat);
     injector->filter(unicode, keycode, modifiers, is_press, autorepeat);
   } else if (msg == "imkitSetFont(QString,int,int,int)"
              || msg == "setFont(QString,int,int,int)")
